@@ -23,7 +23,7 @@ sub BUILD {
   $self->{full_arg0} = $arg0;
 }
 
-our $VERSION = "0.05";
+our $VERSION = "0.06";
 
 __PACKAGE__;
 
@@ -65,7 +65,7 @@ See L<App::Cmd/SYNOPSIS>.
         documentation => "recheck all results",
     );
 
-    sub run {
+    sub execute {
         my ( $self, $opt, $args ) = @_;
 
         # you may ignore $opt, it's in the attributes anyway
