@@ -27,6 +27,7 @@ has app => (
 
 sub _process_args {
     my ( $class, $args, @params ) = @_;
+    local @ARGV = @$args;
 
     my $config_from_file;
     if($class->meta->does_role('MooseX::ConfigFromFile')) {
@@ -46,7 +47,7 @@ sub _process_args {
     }
 
     my %processed = $class->_parse_argv(
-        argv => $args,
+        params => { argv => \@ARGV },
         options => [ $class->_attrs_to_options( $config_from_file ) ],
     );
 
@@ -90,7 +91,7 @@ MooseX::App::Cmd::Command - Base class for L<MooseX::Getopt> based L<App::Cmd::C
         required => 1,
     );
 
-    sub run {
+    sub execute {
         my ( $self, $opts, $args ) = @_;
 
         print $self->option_field; # also available in $opts->{option_field}
