@@ -22,8 +22,8 @@ has widget => (
     documentation => "set widget name",
 );
 
-sub run {
-  my ($self, $opt, $arg) =@_;
+sub execute {
+  my ($self, $opt, $arg) = @_;
 
   die "the widget name is " . $self->widget . " - @$arg\n";
 }
